"""Craiglist friendly city names.

Run this script inorder to print out a dict of
Craiglist city names, for use in creating a valid url.

Attributes:
    - CITIES -- A dict of cities, with the human-friendly
                name as the key
                and url friendly name as the value.
"""
from bs4 import BeautifulSoup
import requests

CITIES = {'sarasota-bradenton': 'sarasota', 'dallas / fort worth': 'dallas', 'manila': 'manila', 'corpus christi': 'corpuschristi', 'panama': 'panama', 'houma': 'houma', 'jerusalem': 'jerusalem', 'winston-salem': 'winstonsalem', 'lakeland': 'lakeland', 'eastern shore': 'easternshore', 'lansing': 'lansing', 'outer banks': 'outerbanks', 'albuquerque': 'albuquerque', 'albany ': 'albanyga', 'luxembourg': 'luxembourg', 'galveston': 'galveston', 'west bank': 'ramallah', 'cagayan de oro': 'cdo', 'lubbock': 'lubbock', 'ciudad juarez': 'juarez', 'southwest michigan': 'swmi', 'mattoon-charleston': 'mattoon', 'saginaw-midland-baycity': 'saginaw', 'huntington-ashland': 'huntington', 'meadville': 'meadville', 'ventura county': 'ventura', 'hattiesburg': 'hattiesburg', 'plattsburgh-adirondacks': 'plattsburgh', 'trois-rivieres': 'troisrivieres', 'lehigh valley': 'allentown', 'medford-ashland': 'medford', 'south bend / michiana': 'southbend', 'scottsbluff / panhandle': 'scottsbluff', 'huntsville / decatur': 'huntsville', 'dublin': 'dublin', 'farmington': 'farmington', 'northwest OK': 'enid', 'susanville': 'susanville', 'prague': 'prague', 'western slope': 'westslope', 'philadelphia': 'philadelphia', 'fortaleza': 'fortaleza', 'lake charles': 'lakecharles', 'strasbourg': 'strasbourg', 'venezuela': 'caracas', 'zurich': 'zurich', 'valdosta': 'valdosta', 'salem': 'salem', 'sendai': 'sendai', 'gold country': 'goldcountry', 'fresno / madera': 'fresno', 'south jersey': 'southjersey', 'bemidji': 'bemidji', 'provo / orem': 'provo', 'salina': 'salina', 'cambridge, UK': 'cambridge', 'aberdeen': 'aberdeen', 'tyler / east TX': 'easttexas', 'fort collins / north CO': 'fortcollins', 'singapore': 'singapore', 'tri-cities': 'tricities', 'oklahoma city': 'oklahomacity', 'st joseph': 'stjoseph', 'east oregon': 'eastoregon', 'belgium': 'brussels', 'niagara region': 'niagara', 'daytona beach': 'daytona', 'muncie / anderson': 'muncie', 'beaumont / port arthur': 'beaumont', 'caribbean islands': 'caribbean', 'northern panhandle': 'wheeling', 'toledo': 'toledo', 'asheville': 'asheville', 'treasure coast': 'treasure', 'springfield ': 'springfieldil', 'central louisiana': 'cenla', 'yuba-sutter': 'yubasutter', 'lancaster': 'lancaster', 'sao paulo': 'saopaulo', 'southwest VA': 'swva', 'twin falls': 'twinfalls', 'gulfport / biloxi': 'gulfport', 'new hampshire': 'nh', 'stillwater': 'stillwater', 'U.S. virgin islands': 'virgin', 'fredericksburg': 'fredericksburg', 'red deer': 'reddeer', 'albany': 'albany', 'washington': 'washingtondc', 'rockford': 'rockford', 'panama city': 'panamacity', 'zanesville / cambridge': 'zanesville', 'visalia-tulare': 'visalia', 'austin': 'austin', 'fargo / moorhead': 'fargo', 'duluth / superior': 'duluth', 'acapulco': 'acapulco', 'bellingham': 'bellingham', 'north central FL': 'lakecity', 'ghana': 'accra', 'porto': 'porto', 'virgin islands': 'virgin', 'lexington': 'lexington', 'baltimore': 'baltimore', 'bhubaneswar': 'bhubaneswar', 'kokomo': 'kokomo', 'reno / tahoe': 'reno', 'sardinia': 'sardinia', 'chongqing': 'chongqing', 'lewiston / clarkston': 'lewiston', 'mason city': 'masoncity', 'guam-micronesia': 'micronesia', 'chatham-kent': 'chatham', 'brasilia': 'brasilia', 'sapporo': 'sapporo', 'new york city': 'newyork', 'curitiba': 'curitiba', 'richmond ': 'richmondin', 'augusta': 'augusta', "xi'an": 'xian', 'napoli / campania': 'naples', 'chicago': 'chicago', 'phoenix': 'phoenix', 'chengdu': 'chengdu', 'helena': 'helena', 'bloomington': 'bloomington', 'hilton head': 'hiltonhead', 'south coast': 'southcoast', 'kootenays': 'kootenays', 'essex': 'essex', 'baleares': 'baleares', 'liverpool': 'liverpool', 'loire valley': 'loire', 'eau claire': 'eauclaire', 'humboldt county': 'humboldt', 'dothan': 'dothan', 'fukuoka': 'fukuoka', 'kamloops': 'kamloops', 'west virginia (old)': 'wv', 'sicilia': 'sicily', 'muskegon': 'muskegon', 'lafayette': 'lafayette', 'east idaho': 'eastidaho', 'tasmania': 'hobart', 'sydney': 'sydney', 'richmond': 'richmond', 'tunisia': 'tunis', 'kaiserslautern': 'kaiserslautern', 'cariboo': 'cariboo', 'nagoya': 'nagoya', 'poconos': 'poconos', 'lausanne': 'lausanne', 'rapid city / west SD': 'rapidcity', 'oaxaca': 'oaxaca', 'sunshine coast': 'sunshine', 'northwest GA': 'nwga', 'toulouse': 'toulouse', 'raleigh / durham / CH': 'raleigh', 'brainerd': 'brainerd', 'darwin': 'darwin', 'show low': 'showlow', 'surat surat': 'surat', 'shreveport': 'shreveport', 'central michigan': 'centralmich', 'tucson': 'tucson', 'flint': 'flint', 'tuscarawas co': 'tuscarawas', 'ottawa-hull-gatineau': 'ottawa', 'western IL': 'quincy', 'ft myers / SW florida': 'fortmyers', 'wausau': 'wausau', 'imperial county': 'imperial', 'twin tiers NY/PA': 'twintiers', 'kingston': 'kingston', 'marseille': 'marseilles', 'sandusky': 'sandusky', 'taiwan': 'taipei', 'fairbanks': 'fairbanks', 'killeen / temple / ft hood': 'killeen', 'brittany': 'rennes', 'croatia': 'zagreb', 'amarillo': 'amarillo', 'birmingham': 'bham', 'whitehorse': 'whitehorse', 'green bay': 'greenbay', 'texarkana': 'texarkana', 'romania': 'bucharest', 'boulder': 'boulder', 'baja california sur': 'bajasur', 'columbus': 'columbus', 'denver': 'denver', 'modesto': 'modesto', 'greece': 'athens', 'stockton': 'stockton', 'meridian': 'meridian', 'los angeles': 'losangeles', 'hangzhou': 'hangzhou', 'frederick': 'frederick', 'london ': 'londonon', 'florence / muscle shoals': 'shoals', 'johannesburg': 'johannesburg', 'ahmedabad': 'ahmedabad', 'eastern kentucky': 'eastky', 'elko': 'elko', 'dubuque': 'dubuque', 'space coast': 'spacecoast', 'klamath falls': 'klamath', 'yuma': 'yuma', 'kalamazoo': 'kalamazoo', 'southwest TX': 'bigbend', 'hampton roads': 'norfolk', 'jaipur': 'jaipur', 'lima / findlay': 'limaohio', 'mankato': 'mankato', 'recife': 'recife', 'gold coast': 'goldcoast', 'geneva': 'geneva', 'hampshire': 'hampshire', 'butte': 'butte', 'charleston': 'charleston', 'hamilton-burlington': 'hamilton', 'fort dodge': 'fortdodge', 'hong kong': 'hongkong', 'altoona-johnstown': 'altoona', 'genoa': 'genoa', 'hawaii': 'honolulu', 'beijing': 'beijing', 'northern WI': 'northernwi', 'budapest': 'budapest', 'reykjavik': 'reykjavik', 'lucknow': 'lucknow', 'malaga': 'malaga', 'harrisonburg': 'harrisonburg', 'canarias': 'canarias', 'savannah / hinesville': 'savannah', 'guelph': 'guelph', 'medicine hat': 'hat', 'kalispell': 'kalispell', 'youngstown': 'youngstown', 'monterrey': 'monterrey', 'mumbai': 'mumbai', 'southern WV': 'swv', 'stuttgart': 'stuttgart', 'dundee': 'dundee', 'ft mcmurray': 'ftmcmurray', 'kolkata (calcutta)': 'kolkata', 'cologne': 'cologne', 'guangzhou': 'guangzhou', 'basel': 'basel', 'durban': 'durban', 'sevilla': 'sevilla', 'perugia': 'perugia', 'charlottesville': 'charlottesville', 'davao city': 'davaocity', 'western maryland': 'westmd', 'zamboanga': 'zamboanga', 'pierre / central SD': 'csd', "st john's": 'newfoundland', 'eastern panhandle': 'martinsburg', 'louisville': 'louisville', 'charleston ': 'charlestonwv', 'appleton-oshkosh-FDL': 'appleton', 'sheboygan': 'sheboygan', 'topeka': 'topeka', 'hermosillo': 'hermosillo', 'northwest KS': 'nwks', 'wilmington': 'wilmington', 'halifax': 'halifax', 'battle creek': 'battlecreek', 'shanghai': 'shanghai', 'rochester ': 'rmn', 'ethiopia': 'addisababa', 'billings': 'billings', 'tallahassee': 'tallahassee', 'bremen': 'bremen', 'monroe': 'monroe', 'yucatan': 'yucatan', 'nicaragua': 'managua', 'sherbrooke': 'sherbrooke', 'jackson ': 'jxn', 'devon & cornwall': 'devon', 'ecuador': 'quito', 'peoria': 'peoria', 'miami / dade': 'miami', 'cadiz': 'cadiz', 'boise': 'boise', 'ithaca': 'ithaca', 'milan': 'milan', 'pretoria': 'pretoria', 'iran': 'tehran', 'skagit / island / SJI': 'skagit', 'guatemala': 'guatemala', 'akron / canton': 'akroncanton', 'scranton / wilkes-barre': 'scranton', 'mendocino county': 'mendocino', 'kenya': 'kenya', 'porto alegre': 'portoalegre', 'inland empire': 'inlandempire', 'dayton / springfield': 'dayton', 'puerto rico': 'puertorico', 'delaware': 'delaware', 'santa maria': 'santamaria', 'parkersburg-marietta': 'parkersburg', 'athens': 'athensga', 'sudbury': 'sudbury', 'frankfurt': 'frankfurt', 'valencia': 'valencia', 'calgary': 'calgary', 'bulgaria': 'bulgaria', 'palm beach county': 'miami', 'new brunswick': 'newbrunswick', 'mohave county': 'mohave', 'columbus ': 'columbusga', 'essen / ruhr': 'essen', 'wichita falls': 'wichitafalls', 'buffalo': 'buffalo', 'upper peninsula': 'up', 'montreal': 'montreal', 'regina': 'regina', 'munich': 'munich', 'shenzhen': 'shenzhen', 'vermont': 'vermont', 'rome': 'rome', 'milwaukee': 'milwaukee', 'northwest CT': 'nwct', 'belo horizonte': 'belohorizonte', 'canberra': 'canberra', 'prince edward island': 'pei', 'mobile': 'mobile', 'new haven': 'newhaven', 'moscow': 'moscow', 'cincinnati': 'cincinnati', 'sheffield': 'sheffield', 'norway': 'oslo', 'clovis / portales': 'clovis', 'saguenay': 'saguenay', 'colombia': 'colombia', 'wichita': 'wichita', 'birmingham / west mids': 'birmingham', 'dalian': 'dalian', 'indonesia': 'jakarta', 'shenyang': 'shenyang', 'pampanga': 'pampanga', 'mazatlan': 'mazatlan', 'kansas city': 'kansascity', 'new orleans': 'neworleans', 'paris': 'paris', 'poland': 'warsaw', 'port huron': 'porthuron', 'jonesboro': 'jonesboro', 'merced': 'merced', 'chautauqua': 'chautauqua', 'san antonio': 'sanantonio', 'fayetteville': 'fayetteville', 'kitchener-waterloo-cambridge': 'kitchener', 'college station': 'collegestation', 'winnipeg': 'winnipeg', 'glasgow': 'glasgow', 'melbourne': 'melbourne', 'moses lake': 'moseslake', 'terre haute': 'terrehaute', 'chillicothe': 'chillicothe', 'madison': 'madison', 'houston': 'houston', 'heidelberg': 'heidelberg', 'goa': 'goa', 'finger lakes': 'fingerlakes', 'memphis': 'memphis', 'joplin': 'joplin', 'berlin': 'berlin', 'fort wayne': 'fortwayne', 'kent': 'kent', 'cumberland valley': 'chambersburg', 'eastern CO': 'eastco', 'vienna': 'vienna', 'seattle-tacoma': 'seattle', 'southern maryland': 'smd', 'delhi': 'delhi', 'columbia / jeff city': 'columbiamo', 'puerto vallarta': 'pv', 'olympic peninsula': 'olympic', 'christchurch': 'christchurch', 'edmonton': 'edmonton', 'cookeville': 'cookeville', 'wenatchee': 'wenatchee', 'tampa bay area': 'tampa', 'waterloo / cedar falls': 'waterloo', 'dominican republic': 'santodomingo', 'montevideo': 'montevideo', 'puebla': 'puebla', 'north platte': 'northplatte', 'champaign urbana': 'chambana', 'waco': 'waco', 'okaloosa / walton': 'okaloosa', 'salt lake city': 'saltlakecity', 'eastern CT': 'newlondon', 'gainesville': 'gainesville', 'monterey bay': 'monterey', 'rochester': 'rochester', 'vancouver': 'vancouver', 'pune': 'pune', 'newcastle, NSW': 'ntl', 'southwest KS': 'swks', 'roseburg': 'roseburg', 'st augustine': 'staugustine', 'south florida': 'miami', 'bristol': 'bristol', 'kennewick-pasco-richland': 'kpr', 'syracuse': 'syracuse', 'cardiff / wales': 'cardiff', 'san diego': 'sandiego', 'holland': 'holland', 'quad cities': 'quadcities', 'san marcos': 'sanmarcos', 'finland': 'helsinki', 'binghamton': 'binghamton', 'lawton': 'lawton', 'oneonta': 'oneonta', 'bilbao': 'bilbao', 'dusseldorf': 'dusseldorf', 'pullman / moscow': 'pullman', 'belfast': 'belfast', 'grand forks': 'grandforks', 'mexico city': 'mexicocity', 'saskatoon': 'saskatoon', "nice / cote d'azur": 'cotedazur', 'pittsburgh': 'pittsburgh', 'cleveland': 'cleveland', 'myrtle beach': 'myrtlebeach', 'florida keys': 'keys', 'western massachusetts': 'westernmass', 'fayetteville ': 'fayar', 'hickory / lenoir': 'hickory', 'clarksville': 'clarksville', 'vietnam': 'vietnam', 'nanjing': 'nanjing', 'north jersey': 'newjersey', 'siskiyou county': 'siskiyou', 'worcester / central MA': 'worcester', 'sault ste marie': 'soo', 'tel aviv': 'telaviv', 'coventry': 'coventry', 'eugene': 'eugene', 'victoria': 'victoria', 'kenai peninsula': 'kenai', 'bowling green': 'bgky', 'lyon': 'lyon', 'indianapolis': 'indianapolis', 'monroe ': 'monroemi', 'hannover': 'hannover', 'winchester': 'winchester', 'derby': 'derby', 'adelaide': 'adelaide', 'chattanooga': 'chattanooga', 'hudson valley': 'hudsonvalley', 'lincoln': 'lincoln', 'owensboro': 'owensboro', 'guanajuato': 'guanajuato', 'bangalore': 'bangalore', 'kuwait': 'kuwait', 'haifa': 'haifa', 'des moines': 'desmoines', 'beirut, lebanon': 'beirut', 'odessa / midland': 'odessa', 'orlando': 'orlando', 'skeena-bulkley': 'skeena', 'prince george': 'princegeorge', 'wuhan': 'wuhan', 'dresden': 'dresden', 'tulsa': 'tulsa', 'veracruz': 'veracruz', 'united arab emirates': 'dubai', 'granada': 'granada', 'perth': 'perth', 'greenville / upstate': 'greenville', 'sioux city': 'siouxcity', 'bordeaux': 'bordeaux', 'windsor': 'windsor', 'jacksonville': 'jacksonville', 'costa rica': 'costarica', 'lisbon': 'lisbon', 'hamburg': 'hamburg', 'fort lauderdale': 'fortlauderdale', 'cairns': 'cairns', 'faro / algarve': 'faro', 'st george': 'stgeorge', 'evansville': 'evansville', 'tijuana': 'tijuana', 'high rockies': 'rockies', 'mcallen / edinburg': 'mcallen', 'laredo': 'laredo', 'owen sound': 'owensound', 'leipzig': 'leipzig', 'las cruces': 'lascruces', 'cape town': 'capetown', 'wellington': 'wellington', 'nanaimo': 'nanaimo', 'colorado springs': 'cosprings', 'buenos aires': 'buenosaires', 'fraser valley': 'abbotsford', 'brownsville': 'brownsville', 'fort smith': 'fortsmith', 'sierra vista': 'sierravista', 'osaka-kobe-kyoto': 'osaka', 'amsterdam / randstad': 'amsterdam', 'grand island': 'grandisland', 'bismarck': 'bismarck', 'kenosha-racine': 'racine', 'pensacola': 'pensacola', 'cape cod / islands': 'capecod', 'territories': 'territories', 'santa fe / taos': 'santafe', 'wyoming': 'wyoming', 'texoma': 'texoma', 'atlanta': 'atlanta', 'pueblo': 'pueblo', 'anchorage / mat-su': 'anchorage', 'heartland florida': 'cfl', 'glens falls': 'glensfalls', 'madrid': 'madrid', 'gadsden-anniston': 'gadsden', 'jersey shore': 'jerseyshore', 'chandigarh': 'chandigarh', 'lille': 'lille', 'yellowknife': 'yellowknife', 'east anglia': 'norwich', 'mansfield': 'mansfield', 'hiroshima': 'hiroshima', 'lafayette / west lafayette': 'tippecanoe', 'belleville': 'belleville', 'peace river country': 'peace', 'grand rapids': 'grandrapids', 'north mississippi': 'northmiss', 'harrisburg': 'harrisburg', 'sweden': 'stockholm', 'eastern montana': 'montana', 'salvador, bahia': 'salvador', 'okinawa': 'okinawa', 'wollongong': 'wollongong', 'st petersburg': 'stpetersburg', 'athens ': 'athensohio', 'barrie': 'barrie', 'reading': 'reading', 'missoula': 'missoula', 'potsdam-canton-massena': 'potsdam', 'brighton': 'brighton', 'bolivia': 'lapaz', 'great falls': 'greatfalls', 'morgantown': 'morgantown', 'bloomington-normal': 'bn', 'chennai (madras)': 'chennai', 'macon / warner robins': 'macon', 'lawrence': 'lawrence', 'ashtabula': 'ashtabula', 'bern': 'bern', 'broward county': 'miami', 'statesboro': 'statesboro', 'el salvador': 'elsalvador', 'nuremberg': 'nuremberg', 'nashville': 'nashville', 'brantford-woodstock': 'brantford', 'oregon coast': 'oregoncoast', 'eastern NC': 'eastnc', 'iloilo': 'iloilo', 'comox valley': 'comoxvalley', 'springfield': 'springfield', 'dunedin': 'dunedin', 'prescott': 'prescott', 'manchester': 'manchester', 'bangladesh': 'bangladesh', 'greensboro': 'greensboro', 'venice / veneto': 'venice', 'bicol region': 'naga', 'corvallis/albany': 'corvallis', 'south dakota': 'sd', 'redding': 'redding', 'leeds': 'leeds', 'orange county': 'orangecounty', 'alicante': 'alicante', 'sioux falls / SE SD': 'siouxfalls', 'janesville': 'janesville', 'annapolis': 'annapolis', 'victoria ': 'victoriatx', 'southeast alaska': 'juneau', 'ogden-clearfield': 'ogden', 'grenoble': 'grenoble', 'ann arbor': 'annarbor', 'quebec city': 'quebec', 'state college': 'pennstate', 'columbia': 'columbia', 'utica-rome-oneida': 'utica', 'brisbane': 'brisbane', 'northeast SD': 'nesd', 'thunder bay': 'thunderbay', 'chico': 'chico', 'danville': 'danville', 'montgomery': 'montgomery', 'florence': 'florencesc', 'peterborough': 'peterborough', 'bacolod': 'bacolod', 'hartford': 'hartford', 'erie': 'erie', 'baton rouge': 'batonrouge', 'york': 'york', 'ames': 'ames', 'decatur': 'decatur', 'long island': 'longisland', 'bologna': 'bologna', 'watertown': 'watertown', 'flagstaff / sedona': 'flagstaff', 'chihuahua': 'chihuahua', 'brunswick': 'brunswick', 'montpellier': 'montpellier', 'ukraine': 'ukraine', 'kerala': 'kerala', 'boston': 'boston', 'st cloud': 'stcloud', 'sacramento': 'sacramento', 'egypt': 'cairo', 'london': 'london', 'east midlands': 'eastmids', 'charlotte': 'charlotte', 'iowa city': 'iowacity', 'jacksonville ': 'onslow', 'iraq': 'baghdad', 'new river valley': 'blacksburg', 'whistler': 'whistler', 'kirksville': 'kirksville', 'southwest MN': 'marshall', 'palm springs': 'palmsprings', 'del rio / eagle pass': 'delrio', 'deep east texas': 'nacogdoches', 'copenhagen': 'copenhagen', 'newcastle / NE england': 'newcastle', 'toronto': 'toronto', 'detroit metro': 'detroit', 'western KY': 'westky', 'el paso': 'elpaso', 'manhattan': 'ksu', 'peru': 'lima', 'central NJ': 'cnj', 'southeast KS': 'seks', 'pakistan': 'pakistan', 'knoxville': 'knoxville', 'san francisco bay area': 'sfbay', 'logan': 'logan', 'morocco': 'casablanca', 'abilene': 'abilene', 'northern michigan': 'nmi', 'lynchburg': 'lynchburg', 'kelowna / okanagan': 'kelowna', 'tuscaloosa': 'tuscaloosa', 'normandy': 'rouen', 'jackson': 'jackson', 'north dakota': 'nd', 'yakima': 'yakima', 'cornwall': 'cornwall', 'southern illinois': 'carbondale', 'bozeman': 'bozeman', 'lake of the ozarks': 'loz', "spokane / coeur d'alene": 'spokane', 'rio de janeiro': 'rio', 'ocala': 'ocala', 'little rock': 'littlerock', 'tokyo': 'tokyo', 'edinburgh': 'edinburgh', 'indore': 'indore', 'bend': 'bend', 'guadalajara': 'guadalajara', 'lethbridge': 'lethbridge', 'southeast missouri': 'semo', 'boone': 'boone', 'malaysia': 'malaysia', 'bath': 'bath', 'maine': 'maine', 'bakersfield': 'bakersfield', 'hyderabad': 'hyderabad', 'portland': 'portland', 'rhode island': 'providence', 'auckland': 'auckland', 'minneapolis / st paul': 'minneapolis', 'barcelona': 'barcelona', 'southeast IA': 'ottumwa', 'roanoke': 'roanoke', 'southwest MS': 'natchez', 'williamsport': 'williamsport', 'roswell / carlsbad': 'roswell', 'las vegas': 'lasvegas', 'thailand': 'bangkok', 'san luis obispo': 'slo', 'la crosse': 'lacrosse', 'omaha / council bluffs': 'omaha', 'seoul': 'seoul', 'hanford-corcoran': 'hanford', 'sarnia': 'sarnia', 'elmira-corning': 'elmira', 'auburn': 'auburn', 'cedar rapids': 'cedarrapids', 'jackson  ': 'jacksontn', 'the thumb': 'thumb', 'la salle co': 'lasalle', 'florence / tuscany': 'florence', 'cebu': 'cebu', 'san angelo': 'sanangelo', 'torino': 'torino', 'santa barbara': 'santabarbara', 'turkey': 'istanbul', 'st louis': 'stlouis', 'chile': 'santiago', 'catskills': 'catskills', 'nottingham': 'nottingham', 'oxford': 'oxford'}

def scrape_cities():
    """Scrape city and link for dict of valid names."""
    r = requests.get("http://www.craigslist.org/about/sites")
    soup = BeautifulSoup(r.text, "html.parser")
    cities = []
    for node in soup.find_all('a'):
        if node.find_parent('li'):
            if (node['href'].startswith('//') and not node['href'].startswith('//www.')):
                city = ()
                link = node['href'][2:]
                link = link.split('.', 1)[0]
                city = node.get_text()
                cities.append((city, link))
    city_dict = {c[0]: c[1] for c in cities}
    return city_dict

        
if __name__ == '__main__':
    cities = scrape_cities()
    print(cities)
    
